@@ -169,7 +169,7 @@ SEXP quoted_arg (SEXP env, SEXP cenv)
     /* Get the pairlist of arguments from ... in the quoted_arg function. */
 
     SEXP dots = findVarInFrame (env, dotdotdot_symbol);
-    if (dots == R_NilValue)
+    if (dots == R_NilValue || dots == R_MissingArg)
         return R_NilValue;
     if (TYPEOF(dots) != DOTSXP)
         error("something wrong in quoted_arg");
@@ -183,6 +183,9 @@ SEXP quoted_arg (SEXP env, SEXP cenv)
         SEXP arg = CAR(dots);
         SEXP sym;
 
+        if (TYPEOF(arg) == PROMSXP && TYPEOF(PRCODE(arg)) == PROMSXP)
+            error("... is not allowed for quoted_arg");
+
         /* Check that the argument is a symbol (or bytecode for a symbol). */
 
         if (!arg_is_symbol(arg,&sym)) {
